from django.conf import settings
from rest_framework.generics import ListAPIView
from arkindex.documents.models import Transcription, Act
from arkindex.documents.serializers.search import TranscriptionSearchResultSerializer, ActSearchResultSerializer
from arkindex.documents.search import search_transcriptions_post, search_acts_post
from arkindex.project.mixins import SearchAPIMixin


class SearchAPIView(SearchAPIMixin, ListAPIView):
    """
    A base class for ES search views
    """
    template_path = None
    es_source = True
    es_query = None
    es_index = None
    es_type = None
    es_sort = None


class TranscriptionSearch(SearchAPIView):
    """
    Search and list transcriptions, using pagination
    """
    serializer_class = TranscriptionSearchResultSerializer
    template_path = 'elastic/search_transcriptions.json'
    es_sort = {"score": {"order": "desc", "mode": "max"}}
    es_index = settings.ES_INDEX_TRANSCRIPTIONS
    es_type = Transcription.INDEX_TYPE

    def post_process(self, *args, **kwargs):
        return search_transcriptions_post(*args)


class ActSearch(SearchAPIView):
    """
    Search for acts containing a specific word
    """
    serializer_class = ActSearchResultSerializer
    template_path = 'elastic/search_acts.json'
    es_source = False
    es_index = settings.ES_INDEX_ACTS
    es_type = Act.INDEX_TYPE

    def post_process(self, *args, **kwargs):
        return search_acts_post(*args)
