#!/usr/bin/env python3
from django.core.management.base import BaseCommand
from arkindex.documents.tasks import import_manifest
import logging

logging.basicConfig(
    level=logging.INFO,
    format='[%(levelname)s] %(message)s',
)


class Command(BaseCommand):
    help = 'Import JSON manifests'

    def add_arguments(self, parser):
        parser.add_argument(
            'manifest_folder',
            help='Folder to recursively search for IIIF manifests, or a URL pointing to a manifest',
            default='.'
        )
        parser.add_argument(
            '--iiif-server',
            type=str,
            help='IDs of IIIF servers where to find images',
            nargs='+'
        )
        parser.add_argument(
            '--corpus-id',
            type=str,
            help='Slug of corpus to import manifests into',
            required=True,
        )
        parser.add_argument(
            '--offline',
            action='store_true',
            default=False,
            help='Allow importer to make network queries',
        )
        parser.add_argument(
            '--no-annotations',
            action='store_false',
            default=True,
            help='Ignore annotation files',
            dest='annotations',
        )
        parser.add_argument(
            '--volume-name',
            help='Override the manifest volume name with a custom name.',
        )

    def handle(self, *args, **options):
        # Handle verbosity level
        verbosity = int(options['verbosity'])
        root_logger = logging.getLogger('')
        if verbosity > 1:
            root_logger.setLevel(logging.DEBUG)

        task = import_manifest.delay(
            options['manifest_folder'],
            server_ids=options.get('iiif-server', []),
            corpus_id=options['corpus_id'],
            offline=options['offline'],
            annotations=options['annotations'],
            volume_name=options.get('volume_name')
        )
        print("Task started with ID {}".format(task.id))
