#!/usr/bin/env python3

from django.core.management.base import BaseCommand
from arkindex.documents.surface import SurfaceImporter
from arkindex.documents.tasks import import_surfaces
import logging

logging.basicConfig(
    format='[%(levelname)s] %(message)s',
    level=logging.INFO
)


class Command(BaseCommand):
    help = "Import surfaces as acts from XML files"

    def add_arguments(self, parser):
        parser.add_argument(
            'xmlpath',
            help='Path to XML file or folder containing XML files for surfaces'
        )
        parser.add_argument(
            'csvpath',
            help='Path to CSV file containing surface-act associations.'
        )
        parser.add_argument(
            '--dry-run',
            action='store_true',
            default=False,
            help='Print matched images for each surface file without importing'
        )
        parser.add_argument(
            '--col-volume',
            default=0,
            type=int,
            help='Column index for volume'
        )
        parser.add_argument(
            '--col-number',
            default=1,
            type=int,
            help='Column index for number'
        )
        parser.add_argument(
            '--col-folio',
            default=2,
            type=int,
            help='Column index for folio'
        )

    def handle(self, *args, **options):
        # Handle verbosity level
        verbosity = int(options['verbosity'])
        root_logger = logging.getLogger('')
        if verbosity > 1:
            root_logger.setLevel(logging.DEBUG)

        if options['dry_run']:
            SurfaceImporter(**options).dry_run()
        else:
            task = import_surfaces.delay(**options)
            print("Task started with ID {}".format(task.id))
