# Generated by Django 2.1 on 2018-08-21 07:32

from django.db import migrations, models
import uuid
import hashlib

_cache = {}


def str_to_uuid(value):
    if value in _cache:
        return _cache[value]

    h = hashlib.md5(value.encode('utf-8')).hexdigest()
    _cache[value] = h
    return h


def convert(apps, schema_editor):
    '''
    Update all corpus ids by hashing their content towards a uuid
    '''

    Corpus = apps.get_model('documents', 'Corpus')
    Element = apps.get_model('documents', 'Element')

    for x in Element.objects.all():
        x.corpus = str_to_uuid(x.corpus)
        x.save()

    for corpus in Corpus.objects.all():
        # Create a new corpus instance, as the id change
        Corpus.objects.create(
            id=str_to_uuid(corpus.id),
            name=corpus.name,
        )

        # Then delete old instance with slug
        nb_deleted, _ = corpus.delete()
        assert nb_deleted == 1


class Migration(migrations.Migration):

    dependencies = [
        ('documents', '0021_move_transcriptions'),
        ('dataimport', '0005_new_corpus_ids'),
    ]

    operations = [
        # Remove constraints
        migrations.AlterField(
            model_name='element',
            name='corpus',
            field=models.CharField(max_length=250),
        ),

        # Link new fields
        migrations.RunPython(convert),

        # Update fields to UUIDs
        migrations.AlterField(
            model_name='element',
            name='corpus',
            field=models.UUIDField(),
        ),
        migrations.AlterField(
            model_name='corpus',
            name='id',
            field=models.UUIDField(),
        ),

        # Apply constraints
        migrations.AlterField(
            model_name='corpus',
            name='id',
            field=models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='element',
            name='corpus',
            field=models.ForeignKey(on_delete=models.deletion.CASCADE, related_name='elements', to='documents.Corpus'),
        ),

        # Add extra field
        migrations.AddField(
            model_name='corpus',
            name='public',
            field=models.BooleanField(default=False),
        ),
    ]
