<?xml version='1.0'?>
<xsl:stylesheet xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:xsl='http://www.w3.org/1999/XSL/Transform' version='1.0'>

    <xsl:output method='html' omit-xml-declaration='yes' indent='no' encoding='utf-8' />

    <xsl:template match="tei:argument">
        <div class="argument"><xsl:apply-templates /></div>
    </xsl:template>

    <!-- division #0 (div) -->
    <xsl:template match="tei:div">
        <xsl:choose>
            <xsl:when test='./@type = "colophon"'>
                <hr />
                <h2><xsl:value-of select='./head' /></h2>
            </xsl:when>
        </xsl:choose>
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="tei:div1">
        <xsl:choose>
            <xsl:when test='./@type = "colophon"'>
                <hr />
            </xsl:when>
        </xsl:choose>
        <h2><a><xsl:attribute name="name"><xsl:value-of select='./@id' /></xsl:attribute><xsl:value-of select='./head' /></a></h2>
        <xsl:apply-templates />
    </xsl:template>

    <!-- division #2 (div2) -->
    <xsl:template match="tei:div2">
        <h3><xsl:value-of select='./@type' /><xsl:text> </xsl:text><xsl:value-of select='./@n' /><xsl:text>. </xsl:text><xsl:value-of select='./head' /></h3>
        <xsl:apply-templates />
    </xsl:template>

    <!-- division #3 (div3) -->
    <xsl:template match="tei:div3">
        <h4><xsl:value-of select='./@type' /><xsl:text> </xsl:text><xsl:value-of select='./@n' /><xsl:text>. </xsl:text><xsl:value-of select='./head' /></h4>
        <xsl:apply-templates />
    </xsl:template>

    <!-- division #4 (div4) -->
    <xsl:template match="tei:div4">
        <h5><xsl:value-of select='./@type' /><xsl:text> </xsl:text><xsl:value-of select='./@n' /><xsl:text>. </xsl:text><xsl:value-of select='./head' /></h5>
        <xsl:apply-templates />
    </xsl:template>

    <!-- division #5 (div5) -->
    <xsl:template match="tei:div5">
        <h6><xsl:value-of select='./@type' /><xsl:text> </xsl:text><xsl:value-of select='./@n' /><xsl:text>. </xsl:text><xsl:value-of select='./head' /></h6>
        <xsl:apply-templates />
    </xsl:template>

    <!-- images (figure) -->
    <xsl:template match="tei:figure">
    <img>
    <xsl:attribute name='src'><xsl:value-of select='./@url' /></xsl:attribute>
    <xsl:choose>
    <xsl:when test='./figDesc'>
        <xsl:attribute name='alt'><xsl:value-of select='normalize-space(./figDesc)' /></xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
            <xsl:attribute name='alt'><xsl:value-of select='./@url' /></xsl:attribute>
    </xsl:otherwise>
    </xsl:choose>
    <xsl:choose>
        <xsl:when test='./@rend = "top"'>
        <xsl:attribute name='align'><xsl:value-of select='./@rend' /></xsl:attribute>
        </xsl:when>
        <xsl:when test='./@rend = "middle"'>
        <xsl:attribute name='align'><xsl:value-of select='./@rend' /></xsl:attribute>
        </xsl:when>
        <xsl:when test='./@rend = "bottom"'>
        <xsl:attribute name='align'><xsl:value-of select='./@rend' /></xsl:attribute>
        </xsl:when>
        <xsl:when test='./@rend = "left"'>
        <xsl:attribute name='align'><xsl:value-of select='./@rend' /></xsl:attribute>
        </xsl:when>
        <xsl:when test='./@rend = "right"'>
        <xsl:attribute name='align'><xsl:value-of select='./@rend' /></xsl:attribute>
        </xsl:when>
        <xsl:otherwise />
    </xsl:choose>
    </img>
    <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:hi">
        <xsl:choose>
            <xsl:when test='./@rend="italic"'>
                <em><xsl:apply-templates /></em>
            </xsl:when>
            <xsl:when test='./@rend = "sup" or ./@rend = "super"'>
                <sup><xsl:apply-templates /></sup>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <!-- figure description (figDesc) -->
    <xsl:template match='tei:figDesc'>
    <span class='caption'><xsl:apply-templates/></span>
    </xsl:template>

    <!-- line break (lb) -->
    <xsl:template match='tei:lb'>
    <br /><xsl:apply-templates />
    </xsl:template>

    <!-- paragraph (p) -->
    <xsl:template match="tei:p">
        <xsl:choose>
            <xsl:when test='./@rend = "right"'>
                <p style='text-align:right'><xsl:apply-templates /></p>
            </xsl:when>
            <xsl:when test='./@rend = "center"'>
                <p style='text-align:center'><xsl:apply-templates /></p>
            </xsl:when>
            <xsl:when test='./@rend = "fiction"'>
                <p class='fiction'><xsl:text>&#160;&#160;&#160;&#160;</xsl:text><xsl:apply-templates /></p>
            </xsl:when>
            <xsl:when test='./@rend = "pre"'>
                <pre><xsl:apply-templates /></pre>
            </xsl:when>
            <xsl:otherwise>
                <p><xsl:apply-templates /></p>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- quote (quote) -->
    <xsl:template match="tei:quote">
        <blockquote><xsl:apply-templates /></blockquote>
    </xsl:template>

    <!-- line group (lg) -->
    <xsl:template match="tei:lg">
        <p><xsl:apply-templates /></p>
    </xsl:template>

    <!-- line (l) -->
    <xsl:template match="tei:l">
        <xsl:if test='@rend = "indent"'>
            <xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
        </xsl:if>
        <xsl:apply-templates /><br />
    </xsl:template>

    <!-- hypertext reference (xref) -->
    <xsl:template match="tei:xref">
    <a><xsl:attribute name='href'><xsl:value-of select='./@url' /></xsl:attribute><xsl:apply-templates /></a>
    </xsl:template>

     <!-- table (table) -->
    <xsl:template match="tei:table">
        <xsl:choose>
            <xsl:when test='./@rend = "left"'>
                <table border='0' align='left'><xsl:apply-templates /></table>
            </xsl:when>
            <xsl:when test='./@rend = "right"'>
                <table border='0' align='right'><xsl:apply-templates /></table>
            </xsl:when>
            <xsl:when test='./@rend = "center"'>
                <table border='0' align='center'><xsl:apply-templates /></table>
            </xsl:when>
            <xsl:otherwise>
                <table border='0'><xsl:apply-templates /></table>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- table row (row) -->
    <xsl:template match="tei:row">
        <xsl:choose>
            <xsl:when test='./@rend = "left"'>
                <tr align='left' valign='top'><xsl:apply-templates /></tr>
            </xsl:when>
            <xsl:when test='./@rend = "right"'>
                <tr align='right' valign='top'><xsl:apply-templates /></tr>
            </xsl:when>
            <xsl:when test='./@rend = "center"'>
                <tr align='center' valign='top'><xsl:apply-templates /></tr>
            </xsl:when>
            <xsl:when test='./@rend = "justify"'>
                <tr align='justify' valign='top'><xsl:apply-templates /></tr>
            </xsl:when>
            <xsl:otherwise>
                <tr valign='top'><xsl:apply-templates /></tr>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- table row (cell) -->
    <xsl:template match="tei:cell">
        <xsl:choose>
            <xsl:when test='./@rend = "left"'>
                <td align='left'><xsl:attribute name='colspan'><xsl:value-of select='@cols' /></xsl:attribute><xsl:apply-templates /></td>
            </xsl:when>
            <xsl:when test='./@rend = "right"'>
                <td align='right'><xsl:attribute name='colspan'><xsl:value-of select='@cols' /></xsl:attribute><xsl:apply-templates /></td>
            </xsl:when>
            <xsl:when test='./@rend = "center"'>
                <td align='center'><xsl:attribute name='colspan'><xsl:value-of select='@cols' /></xsl:attribute><xsl:apply-templates /></td>
            </xsl:when>
            <xsl:when test='./@rend = "justify"'>
                <td align='justify'><xsl:attribute name='colspan'><xsl:value-of select='@cols' /></xsl:attribute><xsl:apply-templates /></td>
            </xsl:when>
            <xsl:otherwise>
                <td><xsl:attribute name='colspan'><xsl:value-of select='@cols' /></xsl:attribute><xsl:apply-templates /></td>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- lists -->
    <!-- cool XPath expressions and logic by bodard gabriel <gabriel.bodard@kcl.ac.uk> -->
    <xsl:template match="tei:list[@type='gloss']">
      <dl><xsl:apply-templates/></dl>
    </xsl:template>

    <xsl:template match="tei:list[@type='ordered']">
      <ol><xsl:apply-templates/></ol>
    </xsl:template>

    <xsl:template match="tei:list[@type='bulleted']">
      <ul><xsl:apply-templates/></ul>
    </xsl:template>

    <xsl:template match="tei:list[@type='simple']">
      <ul style='list-style-type: none'><xsl:apply-templates/></ul>
    </xsl:template>

    <xsl:template match="tei:label[parent::list[@type='gloss']]">
      <dt><xsl:apply-templates/></dt>
    </xsl:template>

    <xsl:template match="tei:item[parent::list[@type='gloss']]">
      <dd><xsl:apply-templates/></dd>
    </xsl:template>

    <xsl:template match="tei:item[parent::list[@type='bulleted']]">
      <li><xsl:apply-templates/></li>
    </xsl:template>

    <xsl:template match="tei:item[parent::list[@type='simple']]">
      <li><xsl:apply-templates/></li>
    </xsl:template>

    <xsl:template match="tei:item[parent::list[@type='ordered']]">
      <li><xsl:apply-templates/></li>
    </xsl:template>


    <!-- do nothing templates -->

    <!-- teiheader (do nothing) -->
    <xsl:template match="tei:teiHeader" />

    <!-- teiheader (do nothing) -->
    <xsl:template match="tei:front/titlePage" />

    <!-- head (head) -->
    <xsl:template match="tei:head" />

</xsl:stylesheet>
