from arkindex.project.tests import FixtureTestCase
from arkindex.documents.models import Element, ElementType


class TestElementManager(FixtureTestCase):
    """Tests for ElementManager class"""

    def setUp(self):
        self.vol = Element.objects.get(name="Volume 2")
        self.reg = Element.objects.get(name="Register 2")
        self.p1 = Element.objects.get(name="Volume 2, page 1r")
        self.p2 = Element.objects.get(name="Volume 2, page 1v")
        self.p3 = Element.objects.get(name="Volume 2, page 2r")
        self.act = Element.objects.create(corpus=self.corpus, name="Act", type=ElementType.Act)
        self.act.add_parent(self.p1)

    def test_get_ascending(self):
        # Use Page1, expect Register and Volume
        ids = Element.objects.get_ascending(self.p1.id)
        self.assertCountEqual(ids, [self.reg, self.vol])

    def test_get_ascending_empty(self):
        # Use Register, expect empty list
        ids = Element.objects.get_ascending(self.vol.id)
        self.assertCountEqual(ids, [])

    def test_get_ascendings(self):
        # Use all three pages, expect Register and Volume thrice
        ids = Element.objects.get_ascendings(self.p1.id, self.p2.id, self.p3.id)
        self.assertCountEqual(ids[self.p1.id], [self.reg, self.vol])
        self.assertCountEqual(ids[self.p2.id], [self.reg, self.vol])
        self.assertCountEqual(ids[self.p3.id], [self.reg, self.vol])

    def test_get_descending(self):
        # Use register, expect all three pages and the act
        ids = Element.objects.get_descending(self.reg.id)
        self.assertCountEqual(ids, [self.p1, self.p2, self.p3, self.act])

    def test_get_descending_empty(self):
        # Use page 2, expect empty list
        ids = Element.objects.get_descending(self.p2.id)
        self.assertCountEqual(ids, [])

    def test_get_descendings(self):
        # Use all pages, expect Act and nothing else
        ids = Element.objects.get_descendings([self.p1.id, self.p2.id, self.p3.id])
        self.assertCountEqual(ids[self.p1.id], [self.act])
        self.assertCountEqual(ids[self.p2.id], [])
        self.assertCountEqual(ids[self.p3.id], [])

    def test_get_related(self):
        # Use page 1, expect Register, Volume and Act
        ids = Element.objects.get_related(self.p1.id)
        self.assertCountEqual(ids, [self.reg, self.vol, self.act])

    def test_get_related_empty(self):
        # Use a element linked to nothing, expect empty list
        alone = Element.objects.create(corpus=self.corpus, name="LonelyPage", type=ElementType.Page)
        ids = Element.objects.get_related(alone.id)
        self.assertCountEqual(ids, [])

    def test_get_ascending_paths(self):
        paths = Element.objects.get_ascending_paths(self.act.id)
        self.assertEqual(len(paths), 1)
        self.assertSequenceEqual(list(paths[0]), [self.vol, self.reg, self.p1])
