from arkindex.project.tests import FixtureTestCase
from arkindex.documents.surface import parse_himanis_volume_name, parse_act_folio
from arkindex.documents.models import Element, ElementType, Page, PageType, PageDirection


class TestSurfaceImporterFunctions(FixtureTestCase):
    """Test surface importing helper functions."""

    def test_parse_himanis_volume_name(self):
        v42 = Element.objects.create(corpus=self.corpus, type=ElementType.Volume, name="Volume JJ 042")
        v43 = Element.objects.create(corpus=self.corpus, type=ElementType.Volume, name="Volume JJ043")
        v300a = Element.objects.create(corpus=self.corpus, type=ElementType.Volume, name="Volume JJ 300A")
        v300b = Element.objects.create(corpus=self.corpus, type=ElementType.Volume, name="Volume JJ300B")
        self.assertEqual(parse_himanis_volume_name('JJ42'), v42)
        self.assertEqual(parse_himanis_volume_name('JJ43'), v43)
        self.assertEqual(parse_himanis_volume_name('JJ043'), v43)
        self.assertEqual(parse_himanis_volume_name('JJ300A'), v300a)
        self.assertEqual(parse_himanis_volume_name('JJ300B'), v300b)
        with self.assertRaises(Element.DoesNotExist):
            parse_himanis_volume_name('JJ4')
        with self.assertRaises(Element.MultipleObjectsReturned):
            parse_himanis_volume_name('JJ300')

    def test_parse_act_folio(self):
        # Make two normal pages
        p1 = Page.objects.create(corpus=self.corpus, name="Page 1", folio="0001r",
                                 nb=1, direction=PageDirection.Recto,
                                 page_type=PageType.Page)
        p2 = Page.objects.create(corpus=self.corpus, name="Page 2", folio="0100v",
                                 nb=2, direction=PageDirection.Verso,
                                 page_type=PageType.Page)
        # A summary page that should be ignored
        p3 = Page.objects.create(corpus=self.corpus, name="Page 2", folio="0100v",
                                 nb=2, direction=PageDirection.Verso,
                                 page_type=PageType.Summary)
        pages = [p1, p2]
        self.assertListEqual(parse_act_folio(pages, "1r-2v"), pages)
        self.assertListEqual(parse_act_folio(pages, "1r 2v"), pages)
        self.assertListEqual(parse_act_folio(pages, "1 2v"), pages)
        self.assertListEqual(parse_act_folio(pages, "Fol. 01r"), [p1])
        self.assertListEqual(parse_act_folio(pages, "foL 02v"), [p2])
        self.assertListEqual(parse_act_folio(pages, "Fol 01"), [p1])
        with self.assertRaises(ValueError):
            parse_act_folio(pages, "not a folio")
        with self.assertRaises(Page.DoesNotExist):
            parse_act_folio(pages, "2")
        with self.assertRaises(Page.MultipleObjectsReturned):
            parse_act_folio([p1, p2, p2, p3], "2v")
