from django.views.generic import TemplateView, DetailView, View
from django.views.generic.detail import SingleObjectMixin
from django.http import HttpResponse
from arkindex.documents.models import Element, ElementType, Act, Page
import io
import csv


class VolumesList(TemplateView):
    """
    List volumes using Vue JS + API
    """
    template_name = 'documents/volumes.html'


class VolumePages(DetailView):
    """
    Show volume pages using Vue JS + API
    """
    template_name = 'documents/volume.page.html'
    queryset = Element.objects.filter(type=ElementType.Volume)
    context_object_name = 'volume'


class VolumeActs(DetailView):
    template_name = 'documents/volume.act.html'
    queryset = Element.objects.filter(type=ElementType.Volume)
    context_object_name = 'volume'


class TranscriptionsSearch(TemplateView):
    """
    Search pages using Vue JS + API
    """
    template_name = 'documents/transcriptions.html'


class ActsSearch(TemplateView):
    """
    Search acts using Vue JS + API
    """
    template_name = 'documents/acts.html'


class DumpActs(SingleObjectMixin, View):
    """
    Dump acts and linked surfaces data for a given volume in CSV format
    """
    queryset = Element.objects.filter(type=ElementType.Volume)

    def get(self, request, *args, **kwargs):
        volume = self.get_object()
        acts = Act.objects.get_descending(volume.id)
        surfaces = Element.objects.get_descendings(
            *acts.values_list('id', flat=True),
            element_type=ElementType.Surface)
        output = io.StringIO()
        writer = csv.writer(output)
        for act in acts:
            if act.id not in surfaces:
                # Also output acts with no surfaces, with empty columns
                writer.writerow([act.number, act.folio, '', '', '', str(act.id), ''])
            else:
                for surface in surfaces[act.id]:
                    page = Page.objects.filter(zone__image=surface.zone.image).first()
                    writer.writerow([
                        act.number,
                        act.folio,
                        surface.name,
                        page.name,
                        str(surface.zone.polygon.center.y),
                        str(act.id),
                        str(surface.id),
                    ])
        response = HttpResponse(output.getvalue(), content_type="text/csv")
        response['Content-Disposition'] = 'attachment; filename="{}.csv"'.format(volume.name)
        return response
